@@ -46,8 +46,8 @@ pandoc_convert <- function(input,
                            verbose = FALSE,
                            wd = NULL) {
 
-  # ensure we've scanned for pandoc
-  find_pandoc()
+  # ensure pandoc is available
+  pandoc_available(error = TRUE)
 
   # evaluate path arguments before changing working directory
   force(output)
@@ -61,7 +61,7 @@ pandoc_convert <- function(input,
   on.exit(setwd(oldwd), add = TRUE)
 
   # input file and formats
-  args <- c(input)
+  args <- pandoc_path_arg(input)
   if (!is.null(to)) {
     if (to == 'html') to <- 'html4'
     if (to == 'pdf') to <- 'latex'
@@ -72,7 +72,7 @@ pandoc_convert <- function(input,
 
   # output file
   if (!is.null(output))
-    args <- c(args, "--output", output)
+    args <- c(args, "--output", pandoc_path_arg(output))
 
   # set pandoc stack size
   args <- prepend_pandoc_stack_size(args)
@@ -308,20 +308,12 @@ pandoc_include_args <- function(in_header = NULL,
 
 #' @rdname pandoc_args
 #' @export
-pandoc_highlight_args <- function(highlight,
-                                  default = "tango") {
-
-  args <- c()
-
-  if (is.null(highlight))
-    args <- c(args, "--no-highlight")
-  else {
-    if (identical(highlight, "default"))
-      highlight <- default
-    args <- c(args, "--highlight-style", highlight)
+pandoc_highlight_args <- function(highlight, default = "tango") {
+  if (is.null(highlight)) {
+    if (pandoc_available("3.8")) "--syntax-highlighting=none" else "--no-highlight"
+  } else {
+    c("--highlight-style", if (identical(highlight, "default")) default else highlight)
   }
-
-  args
 }
 
 #' @rdname pandoc_args
@@ -393,6 +385,9 @@ pandoc_path_arg <- function(path, backslash = TRUE) {
 
   # remove redundant ./ prefix if present
   path <- sub('^[.]/', '', path)
+  # paths starting with - shouldn't be treated as command-line options (#2503)
+  i <- grepl('^-', path) & xfun::is_rel_path(path)
+  path[i] <- paste0('./', path[i])
 
   if (is_windows()) {
     i <- grep(' ', path)
@@ -692,7 +687,7 @@ get_pandoc_version <- function(pandoc_dir) {
   info <- with_pandoc_safe_environment(
     system(paste(shQuote(path), "--version"), intern = TRUE)
   )
-  version <- strsplit(info, "\n")[[1]][1]
+  version <- strsplit(info, "\n", useBytes = TRUE)[[1]][1]
   version <- strsplit(version, " ")[[1]][2]
   components <- strsplit(version, "-")[[1]]
   version <- components[1]
@@ -804,7 +799,6 @@ pandoc_lua_filter_args <- function(lua_files) {
   if (pandoc2.0()) c(rbind("--lua-filter", pandoc_path_arg(lua_files)))
 }
 
-
 # quote args if they need it
 quoted <- function(args) {
 
